# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mmp_metadata_client
from mmp_metadata_client.api.trace_api import TraceApi  # noqa: E501
from mmp_metadata_client.rest import ApiException


class TestTraceApi(unittest.TestCase):
    """TraceApi unit test stubs"""

    def setUp(self):
        self.api = mmp_metadata_client.api.trace_api.TraceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_trace_by_experiment(self):
        """Test case for get_trace_by_experiment

        one specific trace  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
