# coding: utf-8

"""
    MMP Metadata

    This is a API for MMP Metadata  # noqa: E501

    The version of the OpenAPI document: 1.0.0-oas3
    Contact: st116848@stud.uni-stuttgart.de.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import openapi_client
from openapi_client.models.executable import Executable  # noqa: E501
from openapi_client.rest import ApiException


class TestExecutable(unittest.TestCase):
    """Executable unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testExecutable(self):
        """Test Executable"""
        # FIXME: construct object with mandatory attributes with example values
        # model = openapi_client.models.executable.Executable()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
